==============
Wflow Sediment
==============
With the hydromt_wflow plugin, you can easily work with wflow sediment models. This plugin helps you preparing or updating 
several :ref:`components <model_components_sed>` of a wflow sediment model such as topography information, landuse or soil.
The :ref:`main interactions <model_config_sed>` are available from the HydroMT Command Line Interface and allow you to configure 
HydroMT in order to build or update or clip wflow sediment models. Finally for python users, all wflow sediment objects such as forcing, 
staticmaps etc. are available as :ref:`model attributes <model_attibutes_sed>` including some wflow specific ones (on top of the 
`HydroMT model API attributes <https://hydromt.readthedocs.io/en/latest/api/api_model_api.html>_).

.. toctree::
   :maxdepth: 1

   components
   build_configuration
   attributes
